use skynet_ldap_backend::{
    db_init, get_config,
    methods::{
        account_new::post_new_account,
        account_update::post_update_ldap,
        password_reset::{post_password_auth, post_password_reset},
    },
    State,
};

#[async_std::main]
async fn main() -> tide::Result<()> {
    let config = get_config();
    let db = db_init(&config).await?;

    let host_port = config.host_port.clone();

    tide::log::start();

    let state = State {
        db,
        config,
    };

    let mut app = tide::with_state(state);

    app.at("/ldap/update").post(post_update_ldap);
    app.at("/ldap/new").post(post_new_account);
    app.at("/ldap/reset").post(post_password_reset);
    app.at("/ldap/reset/auth").post(post_password_auth);

    app.listen(host_port).await?;
    Ok(())
}
